bioneuralnet.network\_embedding.gnn\_models
===========================================

.. automodule:: bioneuralnet.network_embedding.gnn_models

   
   .. rubric:: Functions

   .. autosummary::
   
      get_activation
      process_dropout
   
   .. rubric:: Classes

   .. autosummary::
   
      GAT
      GCN
      GIN
      SAGE
   